from herre.wards.graphql import ParsedQuery

GET_GRAPH = ParsedQuery("""
    query GetGraph($id: ID, $template: ID){
        graph(id: $id, template: $template){
            diagram
            name
        }
        }
""")


from fluss.graphql.queries.graph import GET_GRAPH
from fluss.diagram import Diagram
from typing import Any, List, Optional
from herre.convenience import GraphQLModel
from typing import ForwardRef
from enum import Enum
from fluss.ward import FlussWard

Graph = ForwardRef("Graph")


class RepresentationVariety(str, Enum):
    VOXEL = "VOXEL"
    MASK = "MASK"
    UNKNOWN = "UNKNOWN"



class Graph(GraphQLModel):
    version: Optional[str]
    name: Optional[str]
    diagram: Optional[Diagram]
    
    class Meta:
        identifier = "graph"
        ward = "fluss"
        get = GET_GRAPH


Graph.update_forward_refs()



from fakts.config.base import Config
from herre.wards.query import TypedQuery
from herre.wards.graphql import GraphQLWard


class FlussConfig(Config):
    host: str
    port: int
    secure: bool

    class Config:
       group = "fluss"

    @property
    def endpoint(self):
        return f"http://{self.host}:{self.port}/graphql"



class FlussWard(GraphQLWard):
    configClass = FlussConfig

    class Meta:
        key = "fluss"



async def open_playground():
    raise NotImplementedError("SSS")



class gql(TypedQuery):
    ward_key = "fluss"
    


